@@ -7,6 +7,8 @@ Created on Thu Dec 17 18:08:58 2020
 
 import numpy as np
 from . import PropensityFactory, ProbeVectorFactory
+PropensityFactory = PropensityFactory.PropensityFactory
+ProbeVectorFactory = ProbeVectorFactory.ProbeVectorFactory
 import matplotlib.pyplot as plt
 from matplotlib.lines import Line2D
 from matplotlib import cm
