@@ -7,11 +7,13 @@ Created on Thu Dec 17 18:13:32 2020
 
 
 from . import SequenceManipMethods
+SequenceManipMethods = SequenceManipMethods.SequenceManipMethods
 from . import PropensityFactory, ProbeVectorFactory
 PropensityFactory = PropensityFactory.PropensityFactory
 ProbeVectorFactory = ProbeVectorFactory.ProbeVectorFactory
 
 from . import CodonDictionaries
+CodonDictionaries = CodonDictionaries.CodonDictionaries
 import matplotlib.pyplot as plt
 from matplotlib import cm
 import matplotlib.patches as mpatches
@@ -227,7 +229,7 @@ class poi():
                 self.multiframe_nt_seq.append(self.nt_seq[n:-(3-n)])
         
         cd = CodonDictionaries()
-        smm = SequenceManipMethods(codons_seq)
+        smm = SequenceManipMethods()
         codons_aa_seq = smm.nt2aa(codons_seq)
         
         for frame in self.multiframe_nt_seq:
